#[non_exhaustive]pub struct ApiError {
pub id: Option<String>,
pub status: Option<u16>,
pub title: Option<String>,
pub detail: Option<String>,
pub source: Option<ErrorSource>,
}Expand description
One structured error within an ErrorResponse.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>Unique error id Schwab assigns; useful when contacting support.
status: Option<u16>HTTP status as Schwab echoes it in the body. Schwab is inconsistent about sending this as a JSON string or a JSON number; both decode here.
title: Option<String>Short error description.
detail: Option<String>Detailed error description.
source: Option<ErrorSource>What in the request triggered the error.