#[non_exhaustive]pub enum ComplexOrderStrategyType {
Show 22 variants
None,
Covered,
Vertical,
BackRatio,
Calendar,
Diagonal,
Straddle,
Strangle,
CollarSynthetic,
Butterfly,
Condor,
IronCondor,
VerticalRoll,
CollarWithStock,
DoubleDiagonal,
UnbalancedButterfly,
UnbalancedCondor,
UnbalancedIronCondor,
UnbalancedVerticalRoll,
MutualFundSwap,
Custom,
Unknown(String),
}Expand description
Multi-leg option strategy shape.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Not a complex strategy.
Covered
Covered call / covered put.
Vertical
Vertical spread.
BackRatio
Back-ratio spread.
Calendar
Calendar (horizontal) spread.
Diagonal
Diagonal spread.
Straddle
Straddle.
Strangle
Strangle.
CollarSynthetic
Synthetic collar.
Butterfly
Butterfly.
Condor
Condor.
IronCondor
Iron condor.
VerticalRoll
Vertical roll.
CollarWithStock
Collar paired with the underlying stock.
DoubleDiagonal
Double diagonal.
UnbalancedButterfly
Unbalanced butterfly.
UnbalancedCondor
Unbalanced condor.
UnbalancedIronCondor
Unbalanced iron condor.
UnbalancedVerticalRoll
Unbalanced vertical roll.
MutualFundSwap
Mutual-fund swap.
Custom
Custom strategy that does not match a named pattern.
Unknown(String)
A wire value Schwab sent that this crate does not recognize. The raw string is preserved so callers can still route on it.